summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexidbshortcutfile.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kexi/core/kexidbshortcutfile.cpp
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kexi/core/kexidbshortcutfile.cpp')
-rw-r--r--kexi/core/kexidbshortcutfile.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/core/kexidbshortcutfile.cpp b/kexi/core/kexidbshortcutfile.cpp
index 451eb66a..01f0adb3 100644
--- a/kexi/core/kexidbshortcutfile.cpp
+++ b/kexi/core/kexidbshortcutfile.cpp
@@ -97,7 +97,7 @@ bool KexiDBShortcutFile::loadProjectData(KexiProjectData& data, TQString* _group
d->isDatabaseShortcut = false;
}
else {
//ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").tqarg(group).tqarg(type)
return false;
}
@@ -194,9 +194,9 @@ bool KexiDBShortcutFile::saveProjectData(const KexiProjectData& data,
groupPrefix = "Database%1"; //do not i18n!
int number = 1;
- while (config.hasGroup(groupPrefix.tqarg(number))) //a new group key couldn't exist
+ while (config.hasGroup(groupPrefix.arg(number))) //a new group key couldn't exist
number++;
- groupKey = groupPrefix.tqarg(number);
+ groupKey = groupPrefix.arg(number);
}
if (_groupKey) //return this one (generated or found)
*_groupKey = groupKey;
@@ -97,7 +97,7 @@ bool KexiDBShortcutFile::loadProjectData(KexiProjectData& data, TQString* _group
}
else {
- //ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").tqarg(group).tqarg(type)
+ //ERR: i18n("No valid "type" field specified for section \"%1\": unknown value \"%2\".").arg(group).arg(type)
return false;
}